/**
    @file ft51_dma_registers.h

    @brief DMA registers library

    Defines registers and bit-masks for direct memory access to/from 
    certain on-chip peripherals.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_DMA_REGISTERS_H__
#define __FT51_DMA_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 176 (0xB0) DMA_CONTROL_1
#define DMA_CONTROL_1                         0xB0

// Register 176 Bit Definitions
#define BIT_DMA_CONTROL_0_SOFT_RESET           0                                 // Write a 1 to reset DMAIO_REGS_0
#define MASK_DMA_CONTROL_0_SOFT_RESET          (0x1 << BIT_DMA_CONTROL_0_SOFT_RESET)
#define BIT_DMA_CONTROL_0_DEV_EN               1                                 // Write a 1 to enable DMAIO_REGS_0
#define MASK_DMA_CONTROL_0_DEV_EN              (0x1 << BIT_DMA_CONTROL_0_DEV_EN)

//------------------------------------------------------------------------------
// Register 177 (0xB1) DMA_ENABLE_1
#define DMA_ENABLE_1                          0xB1

// Register 177 Bit Definitions
#define BIT_DMA_START                          0                                 // IO Peripheral DMA Start
#define MASK_DMA_START                         (0x1 << BIT_DMA_START       )
#define BIT_DMA_STOP                           1                                 // IO Peripheral DMA Stop
#define MASK_DMA_STOP                          (0x1 << BIT_DMA_STOP       )

//------------------------------------------------------------------------------
// Register 178 (0xB2) DMA_IRQ_ENA_1
#define DMA_IRQ_ENA_1                         0xB2

// Register 178 Bit Definitions
#define BIT_DMA_DONE_IEN                      0                                 // IO Peripheral DMA Done IRQ Enable
#define MASK_DMA_DONE_IEN                     (0x1 << BIT_DMA_DONE_IEN)
#define BIT_DMA_FIFO_FULL_IEN                 1                                 // IO Peripheral DMA FIFO Full IRQ Enable
#define MASK_DMA_FIFO_FULL_IEN                (0x1 << BIT_DMA_FIFO_FULL_IEN)
#define BIT_DMA_FIFO_DAVAIL_IEN               2                                 // IO Peripheral DMA FIFO Data Available IRQ Enable
#define MASK_DMA_FIFO_DAVAIL_IEN              (0x1 << BIT_DMA_FIFO_DAVAIL_IEN)

// IO Peripheral DMA Mode: 
// 00 == PUSH (push data from memory to IO), 
// 01 == PULL (pull data from IO to memory), 
// 10 == MEM_COPY (copy data from one memory location to another memory location), 
// 11 == FIFO
#define BIT_DMA_MODE_0                        3
#define MASK_DMA_MODE_0                       (0x1 << BIT_DMA_MODE_0  )
#define BIT_DMA_MODE_1                        4
#define MASK_DMA_MODE_1                       (0x1 << BIT_DMA_MODE_1  )
#define MASK_DMAIO_MODE                       (0x3 << BIT_DMA_MODE_0  )

// Bits 5 and 6: IO Peripheral DMA Set FIFO Size, 00 == 64, 01 == 128, 10 == 256, 11 == 512 Bytes
#define BIT_DMA_FIFO_SIZE_0                   5
#define MASK_DMA_FIFO_SIZE_0                  (0x1 << BIT_DMA_FIFO_SIZE_0  )
#define BIT_DMA_FIFO_SIZE_1                   6
#define MASK_DMA_FIFO_SIZE_1                  (0x1 << BIT_DMA_FIFO_SIZE_1  )

#define MASK_DMAIO_FIFO_SIZE                  (0x3 << BIT_DMA_FIFO_SIZE_0  )

//------------------------------------------------------------------------------
// Register 179 (0xB3) DMA_IRQ_1
#define DMA_IRQ_1                             0xB3

// Register 179 Bit Definitions
#define BIT_DMA_DONE_INT                      0                                 // IO Peripheral DMA Done IRQ
#define MASK_DMA_DONE_INT                     (0x1 << BIT_DMA_DONE_INT)
#define BIT_DMA_FIFO_FULL_INT                 1                                 // IO Peripheral DMA FIFO Full IRQ
#define MASK_DMA_FIFO_FULL_INT                (0x1 << BIT_DMA_FIFO_FULL_INT)
#define BIT_DMA_FIFO_DAVAIL_INT               2                                 // IO Peripheral DMA FIFO Data Available IRQ
#define MASK_DMA_FIFO_DAVAIL_INT              (0x1 << BIT_DMA_FIFO_DAVAIL_INT)

//------------------------------------------------------------------------------
// Register 180 (0xB4) DMA_SRC_MEM_ADDR_L_1
#define DMA_SRC_MEM_ADDR_L_1                  0xB4

// Register 180 Bit Definitions
#define BIT_DMA_SRC_MEM_ADDR_L_0              0                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_0             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_0  )
#define BIT_DMA_SRC_MEM_ADDR_L_1              1                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_1             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_1  )
#define BIT_DMA_SRC_MEM_ADDR_L_2              2                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_2             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_2  )
#define BIT_DMA_SRC_MEM_ADDR_L_3              3                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_3             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_3  )
#define BIT_DMA_SRC_MEM_ADDR_L_4              4                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_4             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_4  )
#define BIT_DMA_SRC_MEM_ADDR_L_5              5                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_5             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_5  )
#define BIT_DMA_SRC_MEM_ADDR_L_6              6                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_6             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_6  )
#define BIT_DMA_SRC_MEM_ADDR_L_7              7                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_7             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_7  )
#define MASK_DMAIO_SRC_MEM_ADDR_L             (0xFF << BIT_DMA_SRC_MEM_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 181 (0xB5) DMA_SRC_MEM_ADDR_U_1
#define DMA_SRC_MEM_ADDR_U_1                  0xB5

// Register 181 Bit Definitions
#define BIT_DMA_SRC_MEM_ADDR_U_0              0                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_0             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_0  )
#define BIT_DMA_SRC_MEM_ADDR_U_1              1                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_1             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_1  )
#define BIT_DMA_SRC_MEM_ADDR_U_2              2                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_2             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_2  )
#define BIT_DMA_SRC_MEM_ADDR_U_3              3                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_3             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_3  )
#define BIT_DMA_SRC_MEM_ADDR_U_4              4                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_4             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_4  )
#define BIT_DMA_SRC_MEM_ADDR_U_5              5                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_5             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_5  )
#define MASK_DMAIO_SRC_MEM_ADDR_U             (0x3F << BIT_DMA_SRC_MEM_ADDR_U_0  )
#define BIT_DMAIO_SRC_MEM_ADDR_ID             7                                 // IO Peripheral DMA Source Memory Address Increment/decrement, 0 == inc mem addr, 1 == dec mem addr
#define MASK_DMAIO_SRC_MEM_ADDR_ID            (0x1 << BIT_DMAIO_SRC_MEM_ADDR_ID)

//------------------------------------------------------------------------------
// Register 182 (0xB6) DMA_DEST_MEM_ADDR_L_1
#define DMA_DEST_MEM_ADDR_L_1                 0xB6

// Register 182 Bit Definitions
#define BIT_DMA_DEST_MEM_ADDR_L_0             0                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_0            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_0  )
#define BIT_DMA_DEST_MEM_ADDR_L_1             1                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_1            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_1  )
#define BIT_DMA_DEST_MEM_ADDR_L_2             2                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_2            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_2  )
#define BIT_DMA_DEST_MEM_ADDR_L_3             3                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_3            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_3  )
#define BIT_DMA_DEST_MEM_ADDR_L_4             4                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_4            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_4  )
#define BIT_DMA_DEST_MEM_ADDR_L_5             5                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_5            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_5  )
#define BIT_DMA_DEST_MEM_ADDR_L_6             6                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_6            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_6  )
#define BIT_DMA_DEST_MEM_ADDR_L_7             7                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_7            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_7  )
#define MASK_DMAIO_DEST_MEM_ADDR_L            (0xFF << BIT_DMA_DEST_MEM_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 183 (0xB7) DMA_DEST_MEM_ADDR_U_1
#define DMA_DEST_MEM_ADDR_U_1                 0xB7

// Register 183 Bit Definitions
#define BIT_DMA_DEST_MEM_ADDR_U_0             0                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_0            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_0  )
#define BIT_DMA_DEST_MEM_ADDR_U_1             1                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_1            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_1  )
#define BIT_DMA_DEST_MEM_ADDR_U_2             2                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_2            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_2  )
#define BIT_DMA_DEST_MEM_ADDR_U_3             3                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_3            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_3  )
#define BIT_DMA_DEST_MEM_ADDR_U_4             4                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_4            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_4  )
#define BIT_DMA_DEST_MEM_ADDR_U_5             5                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_5            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_5  )
#define MASK_DMAIO_DEST_MEM_ADDR_U            (0x3F << BIT_DMA_DEST_MEM_ADDR_U_0  )
#define BIT_DMAIO_DEST_MEM_ADDR_ID            7                                 // IO Peripheral DMA Destination Memory Address Increment/decrement, 0 == inc mem addr, 1 == dec mem addr
#define MASK_DMAIO_DEST_MEM_ADDR_ID           (0x1 << BIT_DMAIO_DEST_MEM_ADDR_ID)

//------------------------------------------------------------------------------
// Register 184 (0xB8) DMA_IO_ADDR_L_1
#define DMA_IO_ADDR_L_1                       0xB8

// Register 184 Bit Definitions
#define BIT_DMA_IO_ADDR_L_0                   0                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_0                  (0x1 << BIT_DMA_IO_ADDR_L_0  )
#define BIT_DMA_IO_ADDR_L_1                   1                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_1                  (0x1 << BIT_DMA_IO_ADDR_L_1  )
#define BIT_DMA_IO_ADDR_L_2                   2                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_2                  (0x1 << BIT_DMA_IO_ADDR_L_2  )
#define BIT_DMA_IO_ADDR_L_3                   3                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_3                  (0x1 << BIT_DMA_IO_ADDR_L_3  )
#define BIT_DMA_IO_ADDR_L_4                   4                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_4                  (0x1 << BIT_DMA_IO_ADDR_L_4  )
#define BIT_DMA_IO_ADDR_L_5                   5                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_5                  (0x1 << BIT_DMA_IO_ADDR_L_5  )
#define BIT_DMA_IO_ADDR_L_6                   6                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_6                  (0x1 << BIT_DMA_IO_ADDR_L_6  )
#define BIT_DMA_IO_ADDR_L_7                   7                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_7                  (0x1 << BIT_DMA_IO_ADDR_L_7  )
#define MASK_DMAIO_IO_ADDR_L                  (0xFF << BIT_DMA_IO_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 185 (0xB9) DMA_IO_ADDR_U_1
#define DMA_IO_ADDR_U_1                       0xB9

// Register 185 Bit Definitions
#define BIT_DMAIO_IO_ADDR_U                   0                                 // IO Peripheral DMA IO Address Register [8]
#define MASK_DMAIO_IO_ADDR_U                  (0x1 << BIT_DMAIO_IO_ADDR_U)
/* Bits 4 to 7 determine which flow control signals to use:
   0 UART,  1 SPI Master,  2 SPI Slave,  3 Parallel245, 
   4 DMA_FIFO,  5 unused,  6 unused,  7 unused
 */
#define BIT_DMA_FCTRL_0                       4
#define MASK_DMA_FCTRL_0                      (0x1 << BIT_DMA_FCTRL_0  )
#define BIT_DMA_FCTRL_1                       5
#define MASK_DMA_FCTRL_1                      (0x1 << BIT_DMA_FCTRL_1  )
#define BIT_DMA_FCTRL_2                       6
#define MASK_DMA_FCTRL_2                      (0x1 << BIT_DMA_FCTRL_2  )
#define BIT_DMA_FCTRL_3                       7
#define MASK_DMA_FCTRL_3                      (0x1 << BIT_DMA_FCTRL_3  )
#define MASK_DMAIO_FCTRL                      (0xF << BIT_DMA_FCTRL_0  )

//------------------------------------------------------------------------------
// Register 186 (0xBA) DMA_TRANS_CNT_L_1
#define DMA_TRANS_CNT_L_1                     0xBA

// Register 186 Bit Definitions
#define BIT_DMA_TRANS_CNT_L_0                 0                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_0                (0x1 << BIT_DMA_TRANS_CNT_L_0  )
#define BIT_DMA_TRANS_CNT_L_1                 1                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_1                (0x1 << BIT_DMA_TRANS_CNT_L_1  )
#define BIT_DMA_TRANS_CNT_L_2                 2                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_2                (0x1 << BIT_DMA_TRANS_CNT_L_2  )
#define BIT_DMA_TRANS_CNT_L_3                 3                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_3                (0x1 << BIT_DMA_TRANS_CNT_L_3  )
#define BIT_DMA_TRANS_CNT_L_4                 4                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_4                (0x1 << BIT_DMA_TRANS_CNT_L_4  )
#define BIT_DMA_TRANS_CNT_L_5                 5                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_5                (0x1 << BIT_DMA_TRANS_CNT_L_5  )
#define BIT_DMA_TRANS_CNT_L_6                 6                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_6                (0x1 << BIT_DMA_TRANS_CNT_L_6  )
#define BIT_DMA_TRANS_CNT_L_7                 7                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_7                (0x1 << BIT_DMA_TRANS_CNT_L_7  )
#define MASK_DMAIO_TRANS_CNT_L                (0xFF << BIT_DMA_TRANS_CNT_L_0  )

//------------------------------------------------------------------------------
// Register 187 (0xBB) DMA_TRANS_CNT_U_1
#define DMA_TRANS_CNT_U_1                     0xBB

// Register 187 Bit Definitions
#define BIT_DMA_TRANS_CNT_U_0                 0                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_0                (0x1 << BIT_DMA_TRANS_CNT_U_0  )
#define BIT_DMA_TRANS_CNT_U_1                 1                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_1                (0x1 << BIT_DMA_TRANS_CNT_U_1  )
#define BIT_DMA_TRANS_CNT_U_2                 2                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_2                (0x1 << BIT_DMA_TRANS_CNT_U_2  )
#define BIT_DMA_TRANS_CNT_U_3                 3                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_3                (0x1 << BIT_DMA_TRANS_CNT_U_3  )
#define BIT_DMA_TRANS_CNT_U_4                 4                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_4                (0x1 << BIT_DMA_TRANS_CNT_U_4  )
#define BIT_DMA_TRANS_CNT_U_5                 5                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_5                (0x1 << BIT_DMA_TRANS_CNT_U_5  )
#define MASK_DMAIO_TRANS_CNT_U                (0x3F << BIT_DMA_TRANS_CNT_U_0  )

//------------------------------------------------------------------------------
// Register 188 (0xBC) DMA_CURR_CNT_L_1
#define DMA_CURR_CNT_L_1                      0xBC

// Register 188 Bit Definitions
#define BIT_DMA_CURR_CNT_L_0                  0                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_0                 (0x1 << BIT_DMA_CURR_CNT_L_0  )
#define BIT_DMA_CURR_CNT_L_1                  1                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_1                 (0x1 << BIT_DMA_CURR_CNT_L_1  )
#define BIT_DMA_CURR_CNT_L_2                  2                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_2                 (0x1 << BIT_DMA_CURR_CNT_L_2  )
#define BIT_DMA_CURR_CNT_L_3                  3                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_3                 (0x1 << BIT_DMA_CURR_CNT_L_3  )
#define BIT_DMA_CURR_CNT_L_4                  4                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_4                 (0x1 << BIT_DMA_CURR_CNT_L_4  )
#define BIT_DMA_CURR_CNT_L_5                  5                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_5                 (0x1 << BIT_DMA_CURR_CNT_L_5  )
#define BIT_DMA_CURR_CNT_L_6                  6                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_6                 (0x1 << BIT_DMA_CURR_CNT_L_6  )
#define BIT_DMA_CURR_CNT_L_7                  7                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_7                 (0x1 << BIT_DMA_CURR_CNT_L_7  )
#define MASK_DMAIO_CURR_CNT_L                 (0xFF << BIT_DMA_CURR_CNT_L_0  )

//------------------------------------------------------------------------------
// Register 189 (0xBD) DMA_CURR_CNT_U_1
#define DMA_CURR_CNT_U_1                      0xBD

// Register 189 Bit Definitions
#define BIT_DMA_CURR_CNT_U_0                  0                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_0                 (0x1 << BIT_DMA_CURR_CNT_U_0  )
#define BIT_DMA_CURR_CNT_U_1                  1                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_1                 (0x1 << BIT_DMA_CURR_CNT_U_1  )
#define BIT_DMA_CURR_CNT_U_2                  2                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_2                 (0x1 << BIT_DMA_CURR_CNT_U_2  )
#define BIT_DMA_CURR_CNT_U_3                  3                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_3                 (0x1 << BIT_DMA_CURR_CNT_U_3  )
#define BIT_DMA_CURR_CNT_U_4                  4                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_4                 (0x1 << BIT_DMA_CURR_CNT_U_4  )
#define BIT_DMA_CURR_CNT_U_5                  5                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_5                 (0x1 << BIT_DMA_CURR_CNT_U_5  )
#define MASK_DMAIO_CURR_CNT_U                 (0x3F << BIT_DMA_CURR_CNT_U_0  )

//------------------------------------------------------------------------------
// Register 190 (0xBE) DMA_FIFO_DATA_1
#define DMA_FIFO_DATA_1                       0xBE

// Register 190 Bit Definitions
#define BIT_DMA_FIFO_DATA_0                   0                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_0                  (0x1 << BIT_DMA_FIFO_DATA_0  )
#define BIT_DMA_FIFO_DATA_1                   1                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_1                  (0x1 << BIT_DMA_FIFO_DATA_1  )
#define BIT_DMA_FIFO_DATA_2                   2                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_2                  (0x1 << BIT_DMA_FIFO_DATA_2  )
#define BIT_DMA_FIFO_DATA_3                   3                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_3                  (0x1 << BIT_DMA_FIFO_DATA_3  )
#define BIT_DMA_FIFO_DATA_4                   4                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_4                  (0x1 << BIT_DMA_FIFO_DATA_4  )
#define BIT_DMA_FIFO_DATA_5                   5                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_5                  (0x1 << BIT_DMA_FIFO_DATA_5  )
#define BIT_DMA_FIFO_DATA_6                   6                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_6                  (0x1 << BIT_DMA_FIFO_DATA_6  )
#define BIT_DMA_FIFO_DATA_7                   7                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_7                  (0x1 << BIT_DMA_FIFO_DATA_7  )
#define MASK_DMAIO_FIFO_DATA                  (0xFF << BIT_DMA_FIFO_DATA_0  )

//------------------------------------------------------------------------------
// Register 191 (0xBF) DMA_AFULL_TRIGGER_1
#define DMA_AFULL_TRIGGER_1                   0xBF

// Register 191 Bit Definitions
#define BIT_DMA_AFULL_TRIGGER_0               0                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_0              (0x1 << BIT_DMA_AFULL_TRIGGER_0  )
#define BIT_DMA_AFULL_TRIGGER_1               1                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_1              (0x1 << BIT_DMA_AFULL_TRIGGER_1  )
#define BIT_DMA_AFULL_TRIGGER_2               2                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_2              (0x1 << BIT_DMA_AFULL_TRIGGER_2  )
#define BIT_DMA_AFULL_TRIGGER_3               3                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_3              (0x1 << BIT_DMA_AFULL_TRIGGER_3  )
#define BIT_DMA_AFULL_TRIGGER_4               4                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_4              (0x1 << BIT_DMA_AFULL_TRIGGER_4  )
#define BIT_DMA_AFULL_TRIGGER_5               5                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_5              (0x1 << BIT_DMA_AFULL_TRIGGER_5  )
#define BIT_DMA_AFULL_TRIGGER_6               6                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_6              (0x1 << BIT_DMA_AFULL_TRIGGER_6  )
#define BIT_DMA_AFULL_TRIGGER_7               7                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_7              (0x1 << BIT_DMA_AFULL_TRIGGER_7  )
#define MASK_DMAIO_AFULL_TRIGGER              (0xFF << BIT_DMA_AFULL_TRIGGER_0  )

//------------------------------------------------------------------------------
// Register 192 (0xC0) DMA_CONTROL_2
#define DMA_CONTROL_2                  0xC0

// Register 192 Bit Definitions
#define BIT_DMA_CONTROL_1_SOFT_RESET           0                                 // Write a 1 to reset DMAIO_REGS_1
#define MASK_DMA_CONTROL_1_SOFT_RESET          (0x1 << BIT_DMA_CONTROL_1_SOFT_RESET)
#define BIT_DMA_CONTROL_1_DEV_EN               1                                 // Write a 1 to enable DMAIO_REGS_1
#define MASK_DMA_CONTROL_1_DEV_EN              (0x1 << BIT_DMA_CONTROL_1_DEV_EN)

//------------------------------------------------------------------------------
// Register 193 (0xC1) DMA_ENABLE_2
#define DMA_ENABLE_2                          0xC1

// Register 193 Bit Definitions
#define BIT_DMA_START                          0                                 // IO Peripheral DMA Start
#define MASK_DMA_START                         (0x1 << BIT_DMA_START       )
#define BIT_DMA_STOP                           1                                 // IO Peripheral DMA Stop
#define MASK_DMA_STOP                          (0x1 << BIT_DMA_STOP       )

//------------------------------------------------------------------------------
// Register 194 (0xC2) DMA_IRQ_ENA_2
#define DMA_IRQ_ENA_2                         0xC2

// Register 194 Bit Definitions
#define BIT_DMA_DONE_IEN                      0                                 // IO Peripheral DMA Done IRQ Enable
#define MASK_DMA_DONE_IEN                     (0x1 << BIT_DMA_DONE_IEN)
#define BIT_DMA_FIFO_FULL_IEN                 1                                 // IO Peripheral DMA FIFO Full IRQ Enable
#define MASK_DMA_FIFO_FULL_IEN                (0x1 << BIT_DMA_FIFO_FULL_IEN)
#define BIT_DMA_FIFO_DAVAIL_IEN               2                                 // IO Peripheral DMA FIFO Data Available IRQ Enable
#define MASK_DMA_FIFO_DAVAIL_IEN              (0x1 << BIT_DMA_FIFO_DAVAIL_IEN)
#define BIT_DMA_MODE_0                        3                                 // IO Peripheral DMA Mode: 00 == PUSH (push data from memory to IO), 01 == PULL (pull data from IO to memory), 10 == MEM_COPY (copy data from one memory location to another memory location), 11 == FIFO
#define MASK_DMA_MODE_0                       (0x1 << BIT_DMA_MODE_0  )
#define BIT_DMA_MODE_1                        4                                 // IO Peripheral DMA Mode: 00 == PUSH (push data from memory to IO), 01 == PULL (pull data from IO to memory), 10 == MEM_COPY (copy data from one memory location to another memory location), 11 == FIFO
#define MASK_DMA_MODE_1                       (0x1 << BIT_DMA_MODE_1  )
#define MASK_DMAIO_MODE                       (0x3 << BIT_DMA_MODE_0  )
#define BIT_DMA_FIFO_SIZE_0                   5                                 // IO Peripheral DMA Set FIFO Size, 00 == 64, 01 == 128, 10 == 256, 11 == 512 Bytes
#define MASK_DMA_FIFO_SIZE_0                  (0x1 << BIT_DMA_FIFO_SIZE_0  )
#define BIT_DMA_FIFO_SIZE_1                   6                                 // IO Peripheral DMA Set FIFO Size, 00 == 64, 01 == 128, 10 == 256, 11 == 512 Bytes
#define MASK_DMA_FIFO_SIZE_1                  (0x1 << BIT_DMA_FIFO_SIZE_1  )
#define MASK_DMAIO_FIFO_SIZE                  (0x3 << BIT_DMA_FIFO_SIZE_0  )

//------------------------------------------------------------------------------
// Register 195 (0xC3) DMA_IRQ_2
#define DMA_IRQ_2                             0xC3

// Register 195 Bit Definitions
#define BIT_DMA_DONE_INT                      0                                 // IO Peripheral DMA Done IRQ
#define MASK_DMA_DONE_INT                     (0x1 << BIT_DMA_DONE_INT)
#define BIT_DMA_FIFO_FULL_INT                 1                                 // IO Peripheral DMA FIFO Full IRQ
#define MASK_DMA_FIFO_FULL_INT                (0x1 << BIT_DMA_FIFO_FULL_INT)
#define BIT_DMA_FIFO_DAVAIL_INT               2                                 // IO Peripheral DMA FIFO Data Available IRQ
#define MASK_DMA_FIFO_DAVAIL_INT              (0x1 << BIT_DMA_FIFO_DAVAIL_INT)

//------------------------------------------------------------------------------
// Register 196 (0xC4) DMA_SRC_MEM_ADDR_L_2
#define DMA_SRC_MEM_ADDR_L_2                  0xC4

// Register 196 Bit Definitions
#define BIT_DMA_SRC_MEM_ADDR_L_0              0                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_0             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_0  )
#define BIT_DMA_SRC_MEM_ADDR_L_1              1                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_1             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_1  )
#define BIT_DMA_SRC_MEM_ADDR_L_2              2                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_2             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_2  )
#define BIT_DMA_SRC_MEM_ADDR_L_3              3                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_3             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_3  )
#define BIT_DMA_SRC_MEM_ADDR_L_4              4                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_4             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_4  )
#define BIT_DMA_SRC_MEM_ADDR_L_5              5                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_5             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_5  )
#define BIT_DMA_SRC_MEM_ADDR_L_6              6                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_6             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_6  )
#define BIT_DMA_SRC_MEM_ADDR_L_7              7                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_7             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_7  )
#define MASK_DMAIO_SRC_MEM_ADDR_L             (0xFF << BIT_DMA_SRC_MEM_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 197 (0xC5) DMA_SRC_MEM_ADDR_U_2
#define DMA_SRC_MEM_ADDR_U_2                  0xC5

// Register 197 Bit Definitions
#define BIT_DMA_SRC_MEM_ADDR_U_0              0                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_0             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_0  )
#define BIT_DMA_SRC_MEM_ADDR_U_1              1                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_1             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_1  )
#define BIT_DMA_SRC_MEM_ADDR_U_2              2                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_2             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_2  )
#define BIT_DMA_SRC_MEM_ADDR_U_3              3                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_3             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_3  )
#define BIT_DMA_SRC_MEM_ADDR_U_4              4                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_4             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_4  )
#define BIT_DMA_SRC_MEM_ADDR_U_5              5                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_5             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_5  )
#define MASK_DMAIO_SRC_MEM_ADDR_U             (0x3F << BIT_DMA_SRC_MEM_ADDR_U_0  )
#define BIT_DMAIO_SRC_MEM_ADDR_ID             7                                 // IO Peripheral DMA Source Memory Address Increment/decrement, 0 == inc mem addr, 1 == dec mem addr
#define MASK_DMAIO_SRC_MEM_ADDR_ID            (0x1 << BIT_DMAIO_SRC_MEM_ADDR_ID)

//------------------------------------------------------------------------------
// Register 198 (0xC6) DMA_DEST_MEM_ADDR_L_2
#define DMA_DEST_MEM_ADDR_L_2                 0xC6

// Register 198 Bit Definitions
#define BIT_DMA_DEST_MEM_ADDR_L_0             0                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_0            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_0  )
#define BIT_DMA_DEST_MEM_ADDR_L_1             1                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_1            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_1  )
#define BIT_DMA_DEST_MEM_ADDR_L_2             2                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_2            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_2  )
#define BIT_DMA_DEST_MEM_ADDR_L_3             3                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_3            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_3  )
#define BIT_DMA_DEST_MEM_ADDR_L_4             4                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_4            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_4  )
#define BIT_DMA_DEST_MEM_ADDR_L_5             5                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_5            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_5  )
#define BIT_DMA_DEST_MEM_ADDR_L_6             6                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_6            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_6  )
#define BIT_DMA_DEST_MEM_ADDR_L_7             7                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_7            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_7  )
#define MASK_DMAIO_DEST_MEM_ADDR_L            (0xFF << BIT_DMA_DEST_MEM_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 199 (0xC7) DMA_DEST_MEM_ADDR_U_2
#define DMA_DEST_MEM_ADDR_U_2                 0xC7

// Register 199 Bit Definitions
#define BIT_DMA_DEST_MEM_ADDR_U_0             0                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_0            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_0  )
#define BIT_DMA_DEST_MEM_ADDR_U_1             1                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_1            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_1  )
#define BIT_DMA_DEST_MEM_ADDR_U_2             2                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_2            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_2  )
#define BIT_DMA_DEST_MEM_ADDR_U_3             3                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_3            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_3  )
#define BIT_DMA_DEST_MEM_ADDR_U_4             4                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_4            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_4  )
#define BIT_DMA_DEST_MEM_ADDR_U_5             5                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_5            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_5  )
#define MASK_DMAIO_DEST_MEM_ADDR_U            (0x3F << BIT_DMA_DEST_MEM_ADDR_U_0  )
#define BIT_DMAIO_DEST_MEM_ADDR_ID            7                                 // IO Peripheral DMA Destination Memory Address Increment/decrement, 0 == inc mem addr, 1 == dec mem addr
#define MASK_DMAIO_DEST_MEM_ADDR_ID           (0x1 << BIT_DMAIO_DEST_MEM_ADDR_ID)

//------------------------------------------------------------------------------
// Register 200 (0xC8) DMA_IO_ADDR_L_2
#define DMA_IO_ADDR_L_2                       0xC8

// Register 200 Bit Definitions
#define BIT_DMA_IO_ADDR_L_0                   0                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_0                  (0x1 << BIT_DMA_IO_ADDR_L_0  )
#define BIT_DMA_IO_ADDR_L_1                   1                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_1                  (0x1 << BIT_DMA_IO_ADDR_L_1  )
#define BIT_DMA_IO_ADDR_L_2                   2                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_2                  (0x1 << BIT_DMA_IO_ADDR_L_2  )
#define BIT_DMA_IO_ADDR_L_3                   3                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_3                  (0x1 << BIT_DMA_IO_ADDR_L_3  )
#define BIT_DMA_IO_ADDR_L_4                   4                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_4                  (0x1 << BIT_DMA_IO_ADDR_L_4  )
#define BIT_DMA_IO_ADDR_L_5                   5                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_5                  (0x1 << BIT_DMA_IO_ADDR_L_5  )
#define BIT_DMA_IO_ADDR_L_6                   6                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_6                  (0x1 << BIT_DMA_IO_ADDR_L_6  )
#define BIT_DMA_IO_ADDR_L_7                   7                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_7                  (0x1 << BIT_DMA_IO_ADDR_L_7  )
#define MASK_DMAIO_IO_ADDR_L                  (0xFF << BIT_DMA_IO_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 201 (0xC9) DMA_IO_ADDR_U_2
#define DMA_IO_ADDR_U_2                       0xC9

// Register 201 Bit Definitions
#define BIT_DMAIO_IO_ADDR_U                   0                                 // IO Peripheral DMA IO Address Register [8]
#define MASK_DMAIO_IO_ADDR_U                  (0x1 << BIT_DMAIO_IO_ADDR_U)
#define BIT_DMA_FCTRL_0                       4                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_0                      (0x1 << BIT_DMA_FCTRL_0  )
#define BIT_DMA_FCTRL_1                       5                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_1                      (0x1 << BIT_DMA_FCTRL_1  )
#define BIT_DMA_FCTRL_2                       6                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_2                      (0x1 << BIT_DMA_FCTRL_2  )
#define BIT_DMA_FCTRL_3                       7                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_3                      (0x1 << BIT_DMA_FCTRL_3  )
#define MASK_DMAIO_FCTRL                      (0xF << BIT_DMA_FCTRL_0  )

//------------------------------------------------------------------------------
// Register 202 (0xCA) DMA_TRANS_CNT_L_2
#define DMA_TRANS_CNT_L_2                     0xCA

// Register 202 Bit Definitions
#define BIT_DMA_TRANS_CNT_L_0                 0                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_0                (0x1 << BIT_DMA_TRANS_CNT_L_0  )
#define BIT_DMA_TRANS_CNT_L_1                 1                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_1                (0x1 << BIT_DMA_TRANS_CNT_L_1  )
#define BIT_DMA_TRANS_CNT_L_2                 2                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_2                (0x1 << BIT_DMA_TRANS_CNT_L_2  )
#define BIT_DMA_TRANS_CNT_L_3                 3                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_3                (0x1 << BIT_DMA_TRANS_CNT_L_3  )
#define BIT_DMA_TRANS_CNT_L_4                 4                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_4                (0x1 << BIT_DMA_TRANS_CNT_L_4  )
#define BIT_DMA_TRANS_CNT_L_5                 5                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_5                (0x1 << BIT_DMA_TRANS_CNT_L_5  )
#define BIT_DMA_TRANS_CNT_L_6                 6                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_6                (0x1 << BIT_DMA_TRANS_CNT_L_6  )
#define BIT_DMA_TRANS_CNT_L_7                 7                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_7                (0x1 << BIT_DMA_TRANS_CNT_L_7  )
#define MASK_DMAIO_TRANS_CNT_L                (0xFF << BIT_DMA_TRANS_CNT_L_0  )

//------------------------------------------------------------------------------
// Register 203 (0xCB) DMA_TRANS_CNT_U_2
#define DMA_TRANS_CNT_U_2                     0xCB

// Register 203 Bit Definitions
#define BIT_DMA_TRANS_CNT_U_0                 0                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_0                (0x1 << BIT_DMA_TRANS_CNT_U_0  )
#define BIT_DMA_TRANS_CNT_U_1                 1                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_1                (0x1 << BIT_DMA_TRANS_CNT_U_1  )
#define BIT_DMA_TRANS_CNT_U_2                 2                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_2                (0x1 << BIT_DMA_TRANS_CNT_U_2  )
#define BIT_DMA_TRANS_CNT_U_3                 3                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_3                (0x1 << BIT_DMA_TRANS_CNT_U_3  )
#define BIT_DMA_TRANS_CNT_U_4                 4                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_4                (0x1 << BIT_DMA_TRANS_CNT_U_4  )
#define BIT_DMA_TRANS_CNT_U_5                 5                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_5                (0x1 << BIT_DMA_TRANS_CNT_U_5  )
#define MASK_DMAIO_TRANS_CNT_U                (0x3F << BIT_DMA_TRANS_CNT_U_0  )

//------------------------------------------------------------------------------
// Register 204 (0xCC) DMA_CURR_CNT_L_2
#define DMA_CURR_CNT_L_2                      0xCC

// Register 204 Bit Definitions
#define BIT_DMA_CURR_CNT_L_0                  0                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_0                 (0x1 << BIT_DMA_CURR_CNT_L_0  )
#define BIT_DMA_CURR_CNT_L_1                  1                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_1                 (0x1 << BIT_DMA_CURR_CNT_L_1  )
#define BIT_DMA_CURR_CNT_L_2                  2                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_2                 (0x1 << BIT_DMA_CURR_CNT_L_2  )
#define BIT_DMA_CURR_CNT_L_3                  3                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_3                 (0x1 << BIT_DMA_CURR_CNT_L_3  )
#define BIT_DMA_CURR_CNT_L_4                  4                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_4                 (0x1 << BIT_DMA_CURR_CNT_L_4  )
#define BIT_DMA_CURR_CNT_L_5                  5                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_5                 (0x1 << BIT_DMA_CURR_CNT_L_5  )
#define BIT_DMA_CURR_CNT_L_6                  6                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_6                 (0x1 << BIT_DMA_CURR_CNT_L_6  )
#define BIT_DMA_CURR_CNT_L_7                  7                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_7                 (0x1 << BIT_DMA_CURR_CNT_L_7  )
#define MASK_DMAIO_CURR_CNT_L                 (0xFF << BIT_DMA_CURR_CNT_L_0  )

//------------------------------------------------------------------------------
// Register 205 (0xCD) DMA_CURR_CNT_U_2
#define DMA_CURR_CNT_U_2                      0xCD

// Register 205 Bit Definitions
#define BIT_DMA_CURR_CNT_U_0                  0                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_0                 (0x1 << BIT_DMA_CURR_CNT_U_0  )
#define BIT_DMA_CURR_CNT_U_1                  1                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_1                 (0x1 << BIT_DMA_CURR_CNT_U_1  )
#define BIT_DMA_CURR_CNT_U_2                  2                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_2                 (0x1 << BIT_DMA_CURR_CNT_U_2  )
#define BIT_DMA_CURR_CNT_U_3                  3                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_3                 (0x1 << BIT_DMA_CURR_CNT_U_3  )
#define BIT_DMA_CURR_CNT_U_4                  4                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_4                 (0x1 << BIT_DMA_CURR_CNT_U_4  )
#define BIT_DMA_CURR_CNT_U_5                  5                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_5                 (0x1 << BIT_DMA_CURR_CNT_U_5  )
#define MASK_DMAIO_CURR_CNT_U                 (0x3F << BIT_DMA_CURR_CNT_U_0  )

//------------------------------------------------------------------------------
// Register 206 (0xCE) DMA_FIFO_DATA_2
#define DMA_FIFO_DATA_2                       0xCE

// Register 206 Bit Definitions
#define BIT_DMA_FIFO_DATA_0                   0                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_0                  (0x1 << BIT_DMA_FIFO_DATA_0  )
#define BIT_DMA_FIFO_DATA_1                   1                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_1                  (0x1 << BIT_DMA_FIFO_DATA_1  )
#define BIT_DMA_FIFO_DATA_2                   2                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_2                  (0x1 << BIT_DMA_FIFO_DATA_2  )
#define BIT_DMA_FIFO_DATA_3                   3                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_3                  (0x1 << BIT_DMA_FIFO_DATA_3  )
#define BIT_DMA_FIFO_DATA_4                   4                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_4                  (0x1 << BIT_DMA_FIFO_DATA_4  )
#define BIT_DMA_FIFO_DATA_5                   5                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_5                  (0x1 << BIT_DMA_FIFO_DATA_5  )
#define BIT_DMA_FIFO_DATA_6                   6                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_6                  (0x1 << BIT_DMA_FIFO_DATA_6  )
#define BIT_DMA_FIFO_DATA_7                   7                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_7                  (0x1 << BIT_DMA_FIFO_DATA_7  )
#define MASK_DMAIO_FIFO_DATA                  (0xFF << BIT_DMA_FIFO_DATA_0  )

//------------------------------------------------------------------------------
// Register 207 (0xCF) DMA_AFULL_TRIGGER_2
#define DMA_AFULL_TRIGGER_2                   0xCF

// Register 207 Bit Definitions
#define BIT_DMA_AFULL_TRIGGER_0               0                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_0              (0x1 << BIT_DMA_AFULL_TRIGGER_0  )
#define BIT_DMA_AFULL_TRIGGER_1               1                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_1              (0x1 << BIT_DMA_AFULL_TRIGGER_1  )
#define BIT_DMA_AFULL_TRIGGER_2               2                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_2              (0x1 << BIT_DMA_AFULL_TRIGGER_2  )
#define BIT_DMA_AFULL_TRIGGER_3               3                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_3              (0x1 << BIT_DMA_AFULL_TRIGGER_3  )
#define BIT_DMA_AFULL_TRIGGER_4               4                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_4              (0x1 << BIT_DMA_AFULL_TRIGGER_4  )
#define BIT_DMA_AFULL_TRIGGER_5               5                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_5              (0x1 << BIT_DMA_AFULL_TRIGGER_5  )
#define BIT_DMA_AFULL_TRIGGER_6               6                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_6              (0x1 << BIT_DMA_AFULL_TRIGGER_6  )
#define BIT_DMA_AFULL_TRIGGER_7               7                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_7              (0x1 << BIT_DMA_AFULL_TRIGGER_7  )
#define MASK_DMAIO_AFULL_TRIGGER              (0xFF << BIT_DMA_AFULL_TRIGGER_0  )

//------------------------------------------------------------------------------
// Register 208 (0xD0) DMA_CONTROL_3
#define DMA_CONTROL_3                  0xD0

// Register 208 Bit Definitions
#define BIT_DMA_CONTROL_2_SOFT_RESET           0                                 // Write a 1 to reset DMAIO_REGS_2
#define MASK_DMA_CONTROL_2_SOFT_RESET          (0x1 << BIT_DMA_CONTROL_2_SOFT_RESET)
#define BIT_DMA_CONTROL_2_DEV_EN               1                                 // Write a 1 to enable DMAIO_REGS_2
#define MASK_DMA_CONTROL_2_DEV_EN              (0x1 << BIT_DMA_CONTROL_2_DEV_EN)

//------------------------------------------------------------------------------
// Register 209 (0xD1) DMA_ENABLE_3
#define DMA_ENABLE_3                          0xD1

// Register 209 Bit Definitions
#define BIT_DMA_START                          0                                 // IO Peripheral DMA Start
#define MASK_DMA_START                         (0x1 << BIT_DMA_START       )
#define BIT_DMA_STOP                           1                                 // IO Peripheral DMA Stop
#define MASK_DMA_STOP                          (0x1 << BIT_DMA_STOP       )

//------------------------------------------------------------------------------
// Register 210 (0xD2) DMA_IRQ_ENA_3
#define DMA_IRQ_ENA_3                         0xD2

// Register 210 Bit Definitions
#define BIT_DMA_DONE_IEN                      0                                 // IO Peripheral DMA Done IRQ Enable
#define MASK_DMA_DONE_IEN                     (0x1 << BIT_DMA_DONE_IEN)
#define BIT_DMA_FIFO_FULL_IEN                 1                                 // IO Peripheral DMA FIFO Full IRQ Enable
#define MASK_DMA_FIFO_FULL_IEN                (0x1 << BIT_DMA_FIFO_FULL_IEN)
#define BIT_DMA_FIFO_DAVAIL_IEN               2                                 // IO Peripheral DMA FIFO Data Available IRQ Enable
#define MASK_DMA_FIFO_DAVAIL_IEN              (0x1 << BIT_DMA_FIFO_DAVAIL_IEN)
#define BIT_DMA_MODE_0                        3                                 // IO Peripheral DMA Mode: 00 == PUSH (push data from memory to IO), 01 == PULL (pull data from IO to memory), 10 == MEM_COPY (copy data from one memory location to another memory location), 11 == FIFO
#define MASK_DMA_MODE_0                       (0x1 << BIT_DMA_MODE_0  )
#define BIT_DMA_MODE_1                        4                                 // IO Peripheral DMA Mode: 00 == PUSH (push data from memory to IO), 01 == PULL (pull data from IO to memory), 10 == MEM_COPY (copy data from one memory location to another memory location), 11 == FIFO
#define MASK_DMA_MODE_1                       (0x1 << BIT_DMA_MODE_1  )
#define MASK_DMAIO_MODE                       (0x3 << BIT_DMA_MODE_0  )
#define BIT_DMA_FIFO_SIZE_0                   5                                 // IO Peripheral DMA Set FIFO Size, 00 == 64, 01 == 128, 10 == 256, 11 == 512 Bytes
#define MASK_DMA_FIFO_SIZE_0                  (0x1 << BIT_DMA_FIFO_SIZE_0  )
#define BIT_DMA_FIFO_SIZE_1                   6                                 // IO Peripheral DMA Set FIFO Size, 00 == 64, 01 == 128, 10 == 256, 11 == 512 Bytes
#define MASK_DMA_FIFO_SIZE_1                  (0x1 << BIT_DMA_FIFO_SIZE_1  )
#define MASK_DMAIO_FIFO_SIZE                  (0x3 << BIT_DMA_FIFO_SIZE_0  )

//------------------------------------------------------------------------------
// Register 211 (0xD3) DMA_IRQ_3
#define DMA_IRQ_3                             0xD3

// Register 211 Bit Definitions
#define BIT_DMA_DONE_INT                      0                                 // IO Peripheral DMA Done IRQ
#define MASK_DMA_DONE_INT                     (0x1 << BIT_DMA_DONE_INT)
#define BIT_DMA_FIFO_FULL_INT                 1                                 // IO Peripheral DMA FIFO Full IRQ
#define MASK_DMA_FIFO_FULL_INT                (0x1 << BIT_DMA_FIFO_FULL_INT)
#define BIT_DMA_FIFO_DAVAIL_INT               2                                 // IO Peripheral DMA FIFO Data Available IRQ
#define MASK_DMA_FIFO_DAVAIL_INT              (0x1 << BIT_DMA_FIFO_DAVAIL_INT)

//------------------------------------------------------------------------------
// Register 212 (0xD4) DMA_SRC_MEM_ADDR_L_3
#define DMA_SRC_MEM_ADDR_L_3                  0xD4

// Register 212 Bit Definitions
#define BIT_DMA_SRC_MEM_ADDR_L_0              0                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_0             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_0  )
#define BIT_DMA_SRC_MEM_ADDR_L_1              1                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_1             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_1  )
#define BIT_DMA_SRC_MEM_ADDR_L_2              2                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_2             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_2  )
#define BIT_DMA_SRC_MEM_ADDR_L_3              3                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_3             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_3  )
#define BIT_DMA_SRC_MEM_ADDR_L_4              4                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_4             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_4  )
#define BIT_DMA_SRC_MEM_ADDR_L_5              5                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_5             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_5  )
#define BIT_DMA_SRC_MEM_ADDR_L_6              6                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_6             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_6  )
#define BIT_DMA_SRC_MEM_ADDR_L_7              7                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_7             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_7  )
#define MASK_DMAIO_SRC_MEM_ADDR_L             (0xFF << BIT_DMA_SRC_MEM_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 213 (0xD5) DMA_SRC_MEM_ADDR_U_3
#define DMA_SRC_MEM_ADDR_U_3                  0xD5

// Register 213 Bit Definitions
#define BIT_DMA_SRC_MEM_ADDR_U_0              0                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_0             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_0  )
#define BIT_DMA_SRC_MEM_ADDR_U_1              1                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_1             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_1  )
#define BIT_DMA_SRC_MEM_ADDR_U_2              2                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_2             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_2  )
#define BIT_DMA_SRC_MEM_ADDR_U_3              3                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_3             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_3  )
#define BIT_DMA_SRC_MEM_ADDR_U_4              4                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_4             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_4  )
#define BIT_DMA_SRC_MEM_ADDR_U_5              5                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_5             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_5  )
#define MASK_DMAIO_SRC_MEM_ADDR_U             (0x3F << BIT_DMA_SRC_MEM_ADDR_U_0  )
#define BIT_DMAIO_SRC_MEM_ADDR_ID             7                                 // IO Peripheral DMA Source Memory Address Increment/decrement, 0 == inc mem addr, 1 == dec mem addr
#define MASK_DMAIO_SRC_MEM_ADDR_ID            (0x1 << BIT_DMAIO_SRC_MEM_ADDR_ID)

//------------------------------------------------------------------------------
// Register 214 (0xD6) DMA_DEST_MEM_ADDR_L_3
#define DMA_DEST_MEM_ADDR_L_3                 0xD6

// Register 214 Bit Definitions
#define BIT_DMA_DEST_MEM_ADDR_L_0             0                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_0            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_0  )
#define BIT_DMA_DEST_MEM_ADDR_L_1             1                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_1            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_1  )
#define BIT_DMA_DEST_MEM_ADDR_L_2             2                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_2            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_2  )
#define BIT_DMA_DEST_MEM_ADDR_L_3             3                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_3            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_3  )
#define BIT_DMA_DEST_MEM_ADDR_L_4             4                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_4            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_4  )
#define BIT_DMA_DEST_MEM_ADDR_L_5             5                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_5            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_5  )
#define BIT_DMA_DEST_MEM_ADDR_L_6             6                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_6            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_6  )
#define BIT_DMA_DEST_MEM_ADDR_L_7             7                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_7            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_7  )
#define MASK_DMAIO_DEST_MEM_ADDR_L            (0xFF << BIT_DMA_DEST_MEM_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 215 (0xD7) DMA_DEST_MEM_ADDR_U_3
#define DMA_DEST_MEM_ADDR_U_3                 0xD7

// Register 215 Bit Definitions
#define BIT_DMA_DEST_MEM_ADDR_U_0             0                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_0            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_0  )
#define BIT_DMA_DEST_MEM_ADDR_U_1             1                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_1            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_1  )
#define BIT_DMA_DEST_MEM_ADDR_U_2             2                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_2            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_2  )
#define BIT_DMA_DEST_MEM_ADDR_U_3             3                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_3            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_3  )
#define BIT_DMA_DEST_MEM_ADDR_U_4             4                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_4            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_4  )
#define BIT_DMA_DEST_MEM_ADDR_U_5             5                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_5            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_5  )
#define MASK_DMAIO_DEST_MEM_ADDR_U            (0x3F << BIT_DMA_DEST_MEM_ADDR_U_0  )
#define BIT_DMAIO_DEST_MEM_ADDR_ID            7                                 // IO Peripheral DMA Destination Memory Address Increment/decrement, 0 == inc mem addr, 1 == dec mem addr
#define MASK_DMAIO_DEST_MEM_ADDR_ID           (0x1 << BIT_DMAIO_DEST_MEM_ADDR_ID)

//------------------------------------------------------------------------------
// Register 216 (0xD8) DMA_IO_ADDR_L_3
#define DMA_IO_ADDR_L_3                       0xD8

// Register 216 Bit Definitions
#define BIT_DMA_IO_ADDR_L_0                   0                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_0                  (0x1 << BIT_DMA_IO_ADDR_L_0  )
#define BIT_DMA_IO_ADDR_L_1                   1                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_1                  (0x1 << BIT_DMA_IO_ADDR_L_1  )
#define BIT_DMA_IO_ADDR_L_2                   2                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_2                  (0x1 << BIT_DMA_IO_ADDR_L_2  )
#define BIT_DMA_IO_ADDR_L_3                   3                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_3                  (0x1 << BIT_DMA_IO_ADDR_L_3  )
#define BIT_DMA_IO_ADDR_L_4                   4                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_4                  (0x1 << BIT_DMA_IO_ADDR_L_4  )
#define BIT_DMA_IO_ADDR_L_5                   5                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_5                  (0x1 << BIT_DMA_IO_ADDR_L_5  )
#define BIT_DMA_IO_ADDR_L_6                   6                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_6                  (0x1 << BIT_DMA_IO_ADDR_L_6  )
#define BIT_DMA_IO_ADDR_L_7                   7                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_7                  (0x1 << BIT_DMA_IO_ADDR_L_7  )
#define MASK_DMAIO_IO_ADDR_L                  (0xFF << BIT_DMA_IO_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 217 (0xD9) DMA_IO_ADDR_U_3
#define DMA_IO_ADDR_U_3                       0xD9

// Register 217 Bit Definitions
#define BIT_DMAIO_IO_ADDR_U                   0                                 // IO Peripheral DMA IO Address Register [8]
#define MASK_DMAIO_IO_ADDR_U                  (0x1 << BIT_DMAIO_IO_ADDR_U)
#define BIT_DMA_FCTRL_0                       4                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_0                      (0x1 << BIT_DMA_FCTRL_0  )
#define BIT_DMA_FCTRL_1                       5                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_1                      (0x1 << BIT_DMA_FCTRL_1  )
#define BIT_DMA_FCTRL_2                       6                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_2                      (0x1 << BIT_DMA_FCTRL_2  )
#define BIT_DMA_FCTRL_3                       7                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_3                      (0x1 << BIT_DMA_FCTRL_3  )
#define MASK_DMAIO_FCTRL                      (0xF << BIT_DMA_FCTRL_0  )

//------------------------------------------------------------------------------
// Register 218 (0xDA) DMA_TRANS_CNT_L_3
#define DMA_TRANS_CNT_L_3                     0xDA

// Register 218 Bit Definitions
#define BIT_DMA_TRANS_CNT_L_0                 0                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_0                (0x1 << BIT_DMA_TRANS_CNT_L_0  )
#define BIT_DMA_TRANS_CNT_L_1                 1                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_1                (0x1 << BIT_DMA_TRANS_CNT_L_1  )
#define BIT_DMA_TRANS_CNT_L_2                 2                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_2                (0x1 << BIT_DMA_TRANS_CNT_L_2  )
#define BIT_DMA_TRANS_CNT_L_3                 3                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_3                (0x1 << BIT_DMA_TRANS_CNT_L_3  )
#define BIT_DMA_TRANS_CNT_L_4                 4                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_4                (0x1 << BIT_DMA_TRANS_CNT_L_4  )
#define BIT_DMA_TRANS_CNT_L_5                 5                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_5                (0x1 << BIT_DMA_TRANS_CNT_L_5  )
#define BIT_DMA_TRANS_CNT_L_6                 6                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_6                (0x1 << BIT_DMA_TRANS_CNT_L_6  )
#define BIT_DMA_TRANS_CNT_L_7                 7                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_7                (0x1 << BIT_DMA_TRANS_CNT_L_7  )
#define MASK_DMAIO_TRANS_CNT_L                (0xFF << BIT_DMA_TRANS_CNT_L_0  )

//------------------------------------------------------------------------------
// Register 219 (0xDB) DMA_TRANS_CNT_U_3
#define DMA_TRANS_CNT_U_3                     0xDB

// Register 219 Bit Definitions
#define BIT_DMA_TRANS_CNT_U_0                 0                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_0                (0x1 << BIT_DMA_TRANS_CNT_U_0  )
#define BIT_DMA_TRANS_CNT_U_1                 1                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_1                (0x1 << BIT_DMA_TRANS_CNT_U_1  )
#define BIT_DMA_TRANS_CNT_U_2                 2                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_2                (0x1 << BIT_DMA_TRANS_CNT_U_2  )
#define BIT_DMA_TRANS_CNT_U_3                 3                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_3                (0x1 << BIT_DMA_TRANS_CNT_U_3  )
#define BIT_DMA_TRANS_CNT_U_4                 4                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_4                (0x1 << BIT_DMA_TRANS_CNT_U_4  )
#define BIT_DMA_TRANS_CNT_U_5                 5                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_5                (0x1 << BIT_DMA_TRANS_CNT_U_5  )
#define MASK_DMAIO_TRANS_CNT_U                (0x3F << BIT_DMA_TRANS_CNT_U_0  )

//------------------------------------------------------------------------------
// Register 220 (0xDC) DMA_CURR_CNT_L_3
#define DMA_CURR_CNT_L_3                      0xDC

// Register 220 Bit Definitions
#define BIT_DMA_CURR_CNT_L_0                  0                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_0                 (0x1 << BIT_DMA_CURR_CNT_L_0  )
#define BIT_DMA_CURR_CNT_L_1                  1                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_1                 (0x1 << BIT_DMA_CURR_CNT_L_1  )
#define BIT_DMA_CURR_CNT_L_2                  2                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_2                 (0x1 << BIT_DMA_CURR_CNT_L_2  )
#define BIT_DMA_CURR_CNT_L_3                  3                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_3                 (0x1 << BIT_DMA_CURR_CNT_L_3  )
#define BIT_DMA_CURR_CNT_L_4                  4                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_4                 (0x1 << BIT_DMA_CURR_CNT_L_4  )
#define BIT_DMA_CURR_CNT_L_5                  5                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_5                 (0x1 << BIT_DMA_CURR_CNT_L_5  )
#define BIT_DMA_CURR_CNT_L_6                  6                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_6                 (0x1 << BIT_DMA_CURR_CNT_L_6  )
#define BIT_DMA_CURR_CNT_L_7                  7                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_7                 (0x1 << BIT_DMA_CURR_CNT_L_7  )
#define MASK_DMAIO_CURR_CNT_L                 (0xFF << BIT_DMA_CURR_CNT_L_0  )

//------------------------------------------------------------------------------
// Register 221 (0xDD) DMA_CURR_CNT_U_3
#define DMA_CURR_CNT_U_3                      0xDD

// Register 221 Bit Definitions
#define BIT_DMA_CURR_CNT_U_0                  0                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_0                 (0x1 << BIT_DMA_CURR_CNT_U_0  )
#define BIT_DMA_CURR_CNT_U_1                  1                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_1                 (0x1 << BIT_DMA_CURR_CNT_U_1  )
#define BIT_DMA_CURR_CNT_U_2                  2                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_2                 (0x1 << BIT_DMA_CURR_CNT_U_2  )
#define BIT_DMA_CURR_CNT_U_3                  3                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_3                 (0x1 << BIT_DMA_CURR_CNT_U_3  )
#define BIT_DMA_CURR_CNT_U_4                  4                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_4                 (0x1 << BIT_DMA_CURR_CNT_U_4  )
#define BIT_DMA_CURR_CNT_U_5                  5                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_5                 (0x1 << BIT_DMA_CURR_CNT_U_5  )
#define MASK_DMAIO_CURR_CNT_U                 (0x3F << BIT_DMA_CURR_CNT_U_0  )

//------------------------------------------------------------------------------
// Register 222 (0xDE) DMA_FIFO_DATA_3
#define DMA_FIFO_DATA_3                       0xDE

// Register 222 Bit Definitions
#define BIT_DMA_FIFO_DATA_0                   0                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_0                  (0x1 << BIT_DMA_FIFO_DATA_0  )
#define BIT_DMA_FIFO_DATA_1                   1                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_1                  (0x1 << BIT_DMA_FIFO_DATA_1  )
#define BIT_DMA_FIFO_DATA_2                   2                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_2                  (0x1 << BIT_DMA_FIFO_DATA_2  )
#define BIT_DMA_FIFO_DATA_3                   3                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_3                  (0x1 << BIT_DMA_FIFO_DATA_3  )
#define BIT_DMA_FIFO_DATA_4                   4                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_4                  (0x1 << BIT_DMA_FIFO_DATA_4  )
#define BIT_DMA_FIFO_DATA_5                   5                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_5                  (0x1 << BIT_DMA_FIFO_DATA_5  )
#define BIT_DMA_FIFO_DATA_6                   6                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_6                  (0x1 << BIT_DMA_FIFO_DATA_6  )
#define BIT_DMA_FIFO_DATA_7                   7                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_7                  (0x1 << BIT_DMA_FIFO_DATA_7  )
#define MASK_DMAIO_FIFO_DATA                  (0xFF << BIT_DMA_FIFO_DATA_0  )

//------------------------------------------------------------------------------
// Register 223 (0xDF) DMA_AFULL_TRIGGER_3
#define DMA_AFULL_TRIGGER_3                   0xDF

// Register 223 Bit Definitions
#define BIT_DMA_AFULL_TRIGGER_0               0                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_0              (0x1 << BIT_DMA_AFULL_TRIGGER_0  )
#define BIT_DMA_AFULL_TRIGGER_1               1                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_1              (0x1 << BIT_DMA_AFULL_TRIGGER_1  )
#define BIT_DMA_AFULL_TRIGGER_2               2                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_2              (0x1 << BIT_DMA_AFULL_TRIGGER_2  )
#define BIT_DMA_AFULL_TRIGGER_3               3                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_3              (0x1 << BIT_DMA_AFULL_TRIGGER_3  )
#define BIT_DMA_AFULL_TRIGGER_4               4                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_4              (0x1 << BIT_DMA_AFULL_TRIGGER_4  )
#define BIT_DMA_AFULL_TRIGGER_5               5                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_5              (0x1 << BIT_DMA_AFULL_TRIGGER_5  )
#define BIT_DMA_AFULL_TRIGGER_6               6                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_6              (0x1 << BIT_DMA_AFULL_TRIGGER_6  )
#define BIT_DMA_AFULL_TRIGGER_7               7                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_7              (0x1 << BIT_DMA_AFULL_TRIGGER_7  )
#define MASK_DMAIO_AFULL_TRIGGER              (0xFF << BIT_DMA_AFULL_TRIGGER_0  )

//------------------------------------------------------------------------------
// Register 224 (0xE0) DMA_CONTROL_4
#define DMA_CONTROL_4                  0xE0

// Register 224 Bit Definitions
#define BIT_DMA_CONTROL_3_SOFT_RESET           0                                 // Write a 1 to reset DMAIO_REGS_3
#define MASK_DMA_CONTROL_3_SOFT_RESET          (0x1 << BIT_DMA_CONTROL_3_SOFT_RESET)
#define BIT_DMA_CONTROL_3_DEV_EN               1                                 // Write a 1 to enable DMAIO_REGS_3
#define MASK_DMA_CONTROL_3_DEV_EN              (0x1 << BIT_DMA_CONTROL_3_DEV_EN)

//------------------------------------------------------------------------------
// Register 225 (0xE1) DMA_ENABLE_4
#define DMA_ENABLE_4                          0xE1

// Register 225 Bit Definitions
#define BIT_DMA_START                          0                                 // IO Peripheral DMA Start
#define MASK_DMA_START                         (0x1 << BIT_DMA_START       )
#define BIT_DMA_STOP                           1                                 // IO Peripheral DMA Stop
#define MASK_DMA_STOP                          (0x1 << BIT_DMA_STOP       )

//------------------------------------------------------------------------------
// Register 226 (0xE2) DMA_IRQ_ENA_4
#define DMA_IRQ_ENA_4                         0xE2

// Register 226 Bit Definitions
#define BIT_DMA_DONE_IEN                      0                                 // IO Peripheral DMA Done IRQ Enable
#define MASK_DMA_DONE_IEN                     (0x1 << BIT_DMA_DONE_IEN)
#define BIT_DMA_FIFO_FULL_IEN                 1                                 // IO Peripheral DMA FIFO Full IRQ Enable
#define MASK_DMA_FIFO_FULL_IEN                (0x1 << BIT_DMA_FIFO_FULL_IEN)
#define BIT_DMA_FIFO_DAVAIL_IEN               2                                 // IO Peripheral DMA FIFO Data Available IRQ Enable
#define MASK_DMA_FIFO_DAVAIL_IEN              (0x1 << BIT_DMA_FIFO_DAVAIL_IEN)
#define BIT_DMA_MODE_0                        3                                 // IO Peripheral DMA Mode: 00 == PUSH (push data from memory to IO), 01 == PULL (pull data from IO to memory), 10 == MEM_COPY (copy data from one memory location to another memory location), 11 == FIFO
#define MASK_DMA_MODE_0                       (0x1 << BIT_DMA_MODE_0  )
#define BIT_DMA_MODE_1                        4                                 // IO Peripheral DMA Mode: 00 == PUSH (push data from memory to IO), 01 == PULL (pull data from IO to memory), 10 == MEM_COPY (copy data from one memory location to another memory location), 11 == FIFO
#define MASK_DMA_MODE_1                       (0x1 << BIT_DMA_MODE_1  )
#define MASK_DMAIO_MODE                       (0x3 << BIT_DMA_MODE_0  )
#define BIT_DMA_FIFO_SIZE_0                   5                                 // IO Peripheral DMA Set FIFO Size, 00 == 64, 01 == 128, 10 == 256, 11 == 512 Bytes
#define MASK_DMA_FIFO_SIZE_0                  (0x1 << BIT_DMA_FIFO_SIZE_0  )
#define BIT_DMA_FIFO_SIZE_1                   6                                 // IO Peripheral DMA Set FIFO Size, 00 == 64, 01 == 128, 10 == 256, 11 == 512 Bytes
#define MASK_DMA_FIFO_SIZE_1                  (0x1 << BIT_DMA_FIFO_SIZE_1  )
#define MASK_DMAIO_FIFO_SIZE                  (0x3 << BIT_DMA_FIFO_SIZE_0  )

//------------------------------------------------------------------------------
// Register 227 (0xE3) DMA_IRQ_4
#define DMA_IRQ_4                             0xE3

// Register 227 Bit Definitions
#define BIT_DMA_DONE_INT                      0                                 // IO Peripheral DMA Done IRQ
#define MASK_DMA_DONE_INT                     (0x1 << BIT_DMA_DONE_INT)
#define BIT_DMA_FIFO_FULL_INT                 1                                 // IO Peripheral DMA FIFO Full IRQ
#define MASK_DMA_FIFO_FULL_INT                (0x1 << BIT_DMA_FIFO_FULL_INT)
#define BIT_DMA_FIFO_DAVAIL_INT               2                                 // IO Peripheral DMA FIFO Data Available IRQ
#define MASK_DMA_FIFO_DAVAIL_INT              (0x1 << BIT_DMA_FIFO_DAVAIL_INT)

//------------------------------------------------------------------------------
// Register 228 (0xE4) DMA_SRC_MEM_ADDR_L_4
#define DMA_SRC_MEM_ADDR_L_4                  0xE4

// Register 228 Bit Definitions
#define BIT_DMA_SRC_MEM_ADDR_L_0              0                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_0             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_0  )
#define BIT_DMA_SRC_MEM_ADDR_L_1              1                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_1             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_1  )
#define BIT_DMA_SRC_MEM_ADDR_L_2              2                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_2             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_2  )
#define BIT_DMA_SRC_MEM_ADDR_L_3              3                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_3             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_3  )
#define BIT_DMA_SRC_MEM_ADDR_L_4              4                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_4             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_4  )
#define BIT_DMA_SRC_MEM_ADDR_L_5              5                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_5             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_5  )
#define BIT_DMA_SRC_MEM_ADDR_L_6              6                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_6             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_6  )
#define BIT_DMA_SRC_MEM_ADDR_L_7              7                                 // IO Peripheral DMA Source Memory Address Register [7..0]
#define MASK_DMA_SRC_MEM_ADDR_L_7             (0x1 << BIT_DMA_SRC_MEM_ADDR_L_7  )
#define MASK_DMAIO_SRC_MEM_ADDR_L             (0xFF << BIT_DMA_SRC_MEM_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 229 (0xE5) DMA_SRC_MEM_ADDR_U_4
#define DMA_SRC_MEM_ADDR_U_4                  0xE5

// Register 229 Bit Definitions
#define BIT_DMA_SRC_MEM_ADDR_U_0              0                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_0             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_0  )
#define BIT_DMA_SRC_MEM_ADDR_U_1              1                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_1             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_1  )
#define BIT_DMA_SRC_MEM_ADDR_U_2              2                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_2             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_2  )
#define BIT_DMA_SRC_MEM_ADDR_U_3              3                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_3             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_3  )
#define BIT_DMA_SRC_MEM_ADDR_U_4              4                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_4             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_4  )
#define BIT_DMA_SRC_MEM_ADDR_U_5              5                                 // IO Peripheral DMA Source Memory Address Register [13..8]
#define MASK_DMA_SRC_MEM_ADDR_U_5             (0x1 << BIT_DMA_SRC_MEM_ADDR_U_5  )
#define MASK_DMAIO_SRC_MEM_ADDR_U             (0x3F << BIT_DMA_SRC_MEM_ADDR_U_0  )
#define BIT_DMAIO_SRC_MEM_ADDR_ID             7                                 // IO Peripheral DMA Source Memory Address Increment/decrement, 0 == inc mem addr, 1 == dec mem addr
#define MASK_DMAIO_SRC_MEM_ADDR_ID            (0x1 << BIT_DMAIO_SRC_MEM_ADDR_ID)

//------------------------------------------------------------------------------
// Register 230 (0xE6) DMA_DEST_MEM_ADDR_L_4
#define DMA_DEST_MEM_ADDR_L_4                 0xE6

// Register 230 Bit Definitions
#define BIT_DMA_DEST_MEM_ADDR_L_0             0                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_0            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_0  )
#define BIT_DMA_DEST_MEM_ADDR_L_1             1                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_1            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_1  )
#define BIT_DMA_DEST_MEM_ADDR_L_2             2                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_2            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_2  )
#define BIT_DMA_DEST_MEM_ADDR_L_3             3                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_3            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_3  )
#define BIT_DMA_DEST_MEM_ADDR_L_4             4                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_4            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_4  )
#define BIT_DMA_DEST_MEM_ADDR_L_5             5                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_5            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_5  )
#define BIT_DMA_DEST_MEM_ADDR_L_6             6                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_6            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_6  )
#define BIT_DMA_DEST_MEM_ADDR_L_7             7                                 // IO Peripheral DMA Destination Memory Address Register [7..0]
#define MASK_DMA_DEST_MEM_ADDR_L_7            (0x1 << BIT_DMA_DEST_MEM_ADDR_L_7  )
#define MASK_DMAIO_DEST_MEM_ADDR_L            (0xFF << BIT_DMA_DEST_MEM_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 231 (0xE7) DMA_DEST_MEM_ADDR_U_4
#define DMA_DEST_MEM_ADDR_U_4                 0xE7

// Register 231 Bit Definitions
#define BIT_DMA_DEST_MEM_ADDR_U_0             0                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_0            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_0  )
#define BIT_DMA_DEST_MEM_ADDR_U_1             1                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_1            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_1  )
#define BIT_DMA_DEST_MEM_ADDR_U_2             2                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_2            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_2  )
#define BIT_DMA_DEST_MEM_ADDR_U_3             3                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_3            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_3  )
#define BIT_DMA_DEST_MEM_ADDR_U_4             4                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_4            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_4  )
#define BIT_DMA_DEST_MEM_ADDR_U_5             5                                 // IO Peripheral DMA Destination Memory Address Register [13..8]
#define MASK_DMA_DEST_MEM_ADDR_U_5            (0x1 << BIT_DMA_DEST_MEM_ADDR_U_5  )
#define MASK_DMAIO_DEST_MEM_ADDR_U            (0x3F << BIT_DMA_DEST_MEM_ADDR_U_0  )
#define BIT_DMAIO_DEST_MEM_ADDR_ID            7                                 // IO Peripheral DMA Destination Memory Address Increment/decrement, 0 == inc mem addr, 1 == dec mem addr
#define MASK_DMAIO_DEST_MEM_ADDR_ID           (0x1 << BIT_DMAIO_DEST_MEM_ADDR_ID)

//------------------------------------------------------------------------------
// Register 232 (0xE8) DMA_IO_ADDR_L_4
#define DMA_IO_ADDR_L_4                       0xE8

// Register 232 Bit Definitions
#define BIT_DMA_IO_ADDR_L_0                   0                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_0                  (0x1 << BIT_DMA_IO_ADDR_L_0  )
#define BIT_DMA_IO_ADDR_L_1                   1                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_1                  (0x1 << BIT_DMA_IO_ADDR_L_1  )
#define BIT_DMA_IO_ADDR_L_2                   2                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_2                  (0x1 << BIT_DMA_IO_ADDR_L_2  )
#define BIT_DMA_IO_ADDR_L_3                   3                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_3                  (0x1 << BIT_DMA_IO_ADDR_L_3  )
#define BIT_DMA_IO_ADDR_L_4                   4                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_4                  (0x1 << BIT_DMA_IO_ADDR_L_4  )
#define BIT_DMA_IO_ADDR_L_5                   5                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_5                  (0x1 << BIT_DMA_IO_ADDR_L_5  )
#define BIT_DMA_IO_ADDR_L_6                   6                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_6                  (0x1 << BIT_DMA_IO_ADDR_L_6  )
#define BIT_DMA_IO_ADDR_L_7                   7                                 // IO Peripheral DMA IO Address Register [7..0]
#define MASK_DMA_IO_ADDR_L_7                  (0x1 << BIT_DMA_IO_ADDR_L_7  )
#define MASK_DMAIO_IO_ADDR_L                  (0xFF << BIT_DMA_IO_ADDR_L_0  )

//------------------------------------------------------------------------------
// Register 233 (0xE9) DMA_IO_ADDR_U_4
#define DMA_IO_ADDR_U_4                       0xE9

// Register 233 Bit Definitions
#define BIT_DMAIO_IO_ADDR_U                   0                                 // IO Peripheral DMA IO Address Register [8]
#define MASK_DMAIO_IO_ADDR_U                  (0x1 << BIT_DMAIO_IO_ADDR_U)
#define BIT_DMA_FCTRL_0                       4                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_0                      (0x1 << BIT_DMA_FCTRL_0  )
#define BIT_DMA_FCTRL_1                       5                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_1                      (0x1 << BIT_DMA_FCTRL_1  )
#define BIT_DMA_FCTRL_2                       6                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_2                      (0x1 << BIT_DMA_FCTRL_2  )
#define BIT_DMA_FCTRL_3                       7                                 // DMA Engine Flow control select, select the appropriate flow control signals to use, 0 == debugger, 1 == uart, 2 == fprog, 3 == spi slave 1, 4 == spi slave 0, 5 == spi master, 6 == fifo_245, 7 == dma_0, 8 == dma_1, 9 == dma_2, 10 == dma_3
#define MASK_DMA_FCTRL_3                      (0x1 << BIT_DMA_FCTRL_3  )
#define MASK_DMAIO_FCTRL                      (0xF << BIT_DMA_FCTRL_0  )

//------------------------------------------------------------------------------
// Register 234 (0xEA) DMA_TRANS_CNT_L_4
#define DMA_TRANS_CNT_L_4                     0xEA

// Register 234 Bit Definitions
#define BIT_DMA_TRANS_CNT_L_0                 0                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_0                (0x1 << BIT_DMA_TRANS_CNT_L_0  )
#define BIT_DMA_TRANS_CNT_L_1                 1                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_1                (0x1 << BIT_DMA_TRANS_CNT_L_1  )
#define BIT_DMA_TRANS_CNT_L_2                 2                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_2                (0x1 << BIT_DMA_TRANS_CNT_L_2  )
#define BIT_DMA_TRANS_CNT_L_3                 3                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_3                (0x1 << BIT_DMA_TRANS_CNT_L_3  )
#define BIT_DMA_TRANS_CNT_L_4                 4                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_4                (0x1 << BIT_DMA_TRANS_CNT_L_4  )
#define BIT_DMA_TRANS_CNT_L_5                 5                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_5                (0x1 << BIT_DMA_TRANS_CNT_L_5  )
#define BIT_DMA_TRANS_CNT_L_6                 6                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_6                (0x1 << BIT_DMA_TRANS_CNT_L_6  )
#define BIT_DMA_TRANS_CNT_L_7                 7                                 // IO Peripheral DMA Transfer Byte Count Register [7..0]
#define MASK_DMA_TRANS_CNT_L_7                (0x1 << BIT_DMA_TRANS_CNT_L_7  )
#define MASK_DMAIO_TRANS_CNT_L                (0xFF << BIT_DMA_TRANS_CNT_L_0  )

//------------------------------------------------------------------------------
// Register 235 (0xEB) DMA_TRANS_CNT_U_4
#define DMA_TRANS_CNT_U_4                     0xEB

// Register 235 Bit Definitions
#define BIT_DMA_TRANS_CNT_U_0                 0                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_0                (0x1 << BIT_DMA_TRANS_CNT_U_0  )
#define BIT_DMA_TRANS_CNT_U_1                 1                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_1                (0x1 << BIT_DMA_TRANS_CNT_U_1  )
#define BIT_DMA_TRANS_CNT_U_2                 2                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_2                (0x1 << BIT_DMA_TRANS_CNT_U_2  )
#define BIT_DMA_TRANS_CNT_U_3                 3                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_3                (0x1 << BIT_DMA_TRANS_CNT_U_3  )
#define BIT_DMA_TRANS_CNT_U_4                 4                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_4                (0x1 << BIT_DMA_TRANS_CNT_U_4  )
#define BIT_DMA_TRANS_CNT_U_5                 5                                 // IO Peripheral DMA Transfer Byte Count Register [13..8]
#define MASK_DMA_TRANS_CNT_U_5                (0x1 << BIT_DMA_TRANS_CNT_U_5  )
#define MASK_DMAIO_TRANS_CNT_U                (0x3F << BIT_DMA_TRANS_CNT_U_0  )

//------------------------------------------------------------------------------
// Register 236 (0xEC) DMA_CURR_CNT_L_4
#define DMA_CURR_CNT_L_4                      0xEC

// Register 236 Bit Definitions
#define BIT_DMA_CURR_CNT_L_0                  0                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_0                 (0x1 << BIT_DMA_CURR_CNT_L_0  )
#define BIT_DMA_CURR_CNT_L_1                  1                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_1                 (0x1 << BIT_DMA_CURR_CNT_L_1  )
#define BIT_DMA_CURR_CNT_L_2                  2                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_2                 (0x1 << BIT_DMA_CURR_CNT_L_2  )
#define BIT_DMA_CURR_CNT_L_3                  3                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_3                 (0x1 << BIT_DMA_CURR_CNT_L_3  )
#define BIT_DMA_CURR_CNT_L_4                  4                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_4                 (0x1 << BIT_DMA_CURR_CNT_L_4  )
#define BIT_DMA_CURR_CNT_L_5                  5                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_5                 (0x1 << BIT_DMA_CURR_CNT_L_5  )
#define BIT_DMA_CURR_CNT_L_6                  6                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_6                 (0x1 << BIT_DMA_CURR_CNT_L_6  )
#define BIT_DMA_CURR_CNT_L_7                  7                                 // IO Peripheral DMA Current Transfer Byte Count Register [7..0]
#define MASK_DMA_CURR_CNT_L_7                 (0x1 << BIT_DMA_CURR_CNT_L_7  )
#define MASK_DMAIO_CURR_CNT_L                 (0xFF << BIT_DMA_CURR_CNT_L_0  )

//------------------------------------------------------------------------------
// Register 237 (0xED) DMA_CURR_CNT_U_4
#define DMA_CURR_CNT_U_4                      0xED

// Register 237 Bit Definitions
#define BIT_DMA_CURR_CNT_U_0                  0                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_0                 (0x1 << BIT_DMA_CURR_CNT_U_0  )
#define BIT_DMA_CURR_CNT_U_1                  1                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_1                 (0x1 << BIT_DMA_CURR_CNT_U_1  )
#define BIT_DMA_CURR_CNT_U_2                  2                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_2                 (0x1 << BIT_DMA_CURR_CNT_U_2  )
#define BIT_DMA_CURR_CNT_U_3                  3                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_3                 (0x1 << BIT_DMA_CURR_CNT_U_3  )
#define BIT_DMA_CURR_CNT_U_4                  4                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_4                 (0x1 << BIT_DMA_CURR_CNT_U_4  )
#define BIT_DMA_CURR_CNT_U_5                  5                                 // IO Peripheral DMA Current Transfer Byte Count Register [13..8]
#define MASK_DMA_CURR_CNT_U_5                 (0x1 << BIT_DMA_CURR_CNT_U_5  )
#define MASK_DMAIO_CURR_CNT_U                 (0x3F << BIT_DMA_CURR_CNT_U_0  )

//------------------------------------------------------------------------------
// Register 238 (0xEE) DMA_FIFO_DATA_4
#define DMA_FIFO_DATA_4                       0xEE

// Register 238 Bit Definitions
#define BIT_DMA_FIFO_DATA_0                   0                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_0                  (0x1 << BIT_DMA_FIFO_DATA_0  )
#define BIT_DMA_FIFO_DATA_1                   1                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_1                  (0x1 << BIT_DMA_FIFO_DATA_1  )
#define BIT_DMA_FIFO_DATA_2                   2                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_2                  (0x1 << BIT_DMA_FIFO_DATA_2  )
#define BIT_DMA_FIFO_DATA_3                   3                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_3                  (0x1 << BIT_DMA_FIFO_DATA_3  )
#define BIT_DMA_FIFO_DATA_4                   4                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_4                  (0x1 << BIT_DMA_FIFO_DATA_4  )
#define BIT_DMA_FIFO_DATA_5                   5                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_5                  (0x1 << BIT_DMA_FIFO_DATA_5  )
#define BIT_DMA_FIFO_DATA_6                   6                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_6                  (0x1 << BIT_DMA_FIFO_DATA_6  )
#define BIT_DMA_FIFO_DATA_7                   7                                 // IO Peripheral DMA FIFO DATA
#define MASK_DMA_FIFO_DATA_7                  (0x1 << BIT_DMA_FIFO_DATA_7  )
#define MASK_DMAIO_FIFO_DATA                  (0xFF << BIT_DMA_FIFO_DATA_0  )

//------------------------------------------------------------------------------
// Register 239 (0xEF) DMA_AFULL_TRIGGER_4
#define DMA_AFULL_TRIGGER_4                   0xEF

// Register 239 Bit Definitions
#define BIT_DMA_AFULL_TRIGGER_0               0                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_0              (0x1 << BIT_DMA_AFULL_TRIGGER_0  )
#define BIT_DMA_AFULL_TRIGGER_1               1                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_1              (0x1 << BIT_DMA_AFULL_TRIGGER_1  )
#define BIT_DMA_AFULL_TRIGGER_2               2                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_2              (0x1 << BIT_DMA_AFULL_TRIGGER_2  )
#define BIT_DMA_AFULL_TRIGGER_3               3                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_3              (0x1 << BIT_DMA_AFULL_TRIGGER_3  )
#define BIT_DMA_AFULL_TRIGGER_4               4                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_4              (0x1 << BIT_DMA_AFULL_TRIGGER_4  )
#define BIT_DMA_AFULL_TRIGGER_5               5                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_5              (0x1 << BIT_DMA_AFULL_TRIGGER_5  )
#define BIT_DMA_AFULL_TRIGGER_6               6                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_6              (0x1 << BIT_DMA_AFULL_TRIGGER_6  )
#define BIT_DMA_AFULL_TRIGGER_7               7                                 // IO Peripheral DMA Almost Full Trigger Value
#define MASK_DMA_AFULL_TRIGGER_7              (0x1 << BIT_DMA_AFULL_TRIGGER_7  )
#define MASK_DMAIO_AFULL_TRIGGER              (0xFF << BIT_DMA_AFULL_TRIGGER_0  )

#endif // __FT51_DMA_REGISTERS_H__
